@@ -5,7 +5,7 @@ use warnings;
 use base 'My::Builder';
 
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use File::Spec qw(devnull);
+use File::Spec;
 use File::Glob qw(glob);
 use File::Copy;
 use Config;
@@ -104,6 +104,11 @@ sub build_binaries {
     printf STDERR ("mod:% 20s version:% 9s prefix:%s\n", $list{$_}, $v, $p) if $self->notes('build_debug_info');
   }
 
+  #detect pkg-config
+  my $pkgcfg = $self->run_stdout2str(qw[pkg-config --version]);
+  $has{'pkg-config'} = $pkgcfg ? 1 : 0;
+  $has_details{'pkg-config'} = { version=>$pkgcfg, prefix=>$self->run_stdout2str(qw[which pkg-config]) };
+  
   $has{l_gtk}   = $has{gtk}    && $self->check_lib( [] , `pkg-config --cflags gtk+-2.0 2>/dev/null`,     `pkg-config --libs gtk+-2.0 2>/dev/null`);
   $has{l_gtkx11}= $has{gtkx11} && $self->check_lib( [] , `pkg-config --cflags gtk+-x11-2.0 2>/dev/null`, `pkg-config --libs gtk+-x11-2.0 2>/dev/null`);
   $has{l_gdk}   = $has{gdk}    && $self->check_lib( [] , `pkg-config --cflags gdk-2.0 2>/dev/null`,      `pkg-config --libs gdk-2.0 2>/dev/null`);
@@ -181,6 +186,17 @@ sub build_binaries {
 
   my @makeopts  = qw[NO_DYNAMIC=Yes USE_NODEPEND=Yes];
   #my @makeopts  = qw[NO_STATIC=Yes USE_NODEPEND=Yes];
+  
+  #On solaris, some tools like 'ar' are not in the default PATH, but in /usr/???/bin    
+  if ($^O eq 'solaris') {
+    my ($ar, $ranlib);
+    for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
+      $ar = "$_/ar" if (!$ar && -x "$_/ar");
+      $ranlib = "$_/ranlib" if (!$ranlib && -x "$_/ranlib");
+    }
+    push @makeopts, "AR=$ar" if $ar;
+    push @makeopts, "RANLIB=$ranlib" if $ranlib;
+  }
 
   #choose GUI subsystem, priorities if multiple subsystems detected: 1. GTK, 2. X11/Motif
   my @libs;
@@ -206,8 +222,22 @@ sub build_binaries {
     warn "###WARNING### No supported GUI subsystem detected!\n";
   }
 
-  if ($self->notes('build_debug_info') || !$build_target) {
-    print STDERR "has: $has{$_} - $_\n" foreach (sort keys %has);
+  if ($self->notes('build_debug_info') || ( !$build_target && $ENV{AUTOMATED_TESTING} ) ) {
+    foreach (sort keys %has) {
+      my $msg = "has: $has{$_} - $_";
+      $msg .= "; version=" . $has_details{$_}->{version} if $has_details{$_}->{version};
+      $msg .= "; prefix="  . $has_details{$_}->{prefix}  if $has_details{$_}->{prefix};
+      print STDERR $msg, "\n";
+    }
+
+    print STDERR "Dumping some pkg-info:\n";
+    print STDERR "[gtk2 cflags] " . $self->run_stdout2str(qw[pkg-config --cflags gtk+-2.0]) . "\n";
+    print STDERR "[gtk2 libs  ] " . $self->run_stdout2str(qw[pkg-config --libs gtk+-2.0]) . "\n";
+    for my $pkg (qw[gtk+-2.0 gl glu glut x11 xt xext xmu]) {
+      print STDERR "[prefix     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=prefix], $pkg) . "\n";
+      print STDERR "[libdir     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=libdir], $pkg) . "\n";
+      print STDERR "[includedir $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=includedir], $pkg) . "\n";
+    }
 
     print STDERR "Brute force lookup:\n";
     my $re = qr/\/(Xlib.h|Xm.h|gtk.h|cairo.h|glu.h|glut.h|gl.h|freetype.h|gtkprintunixdialog.h|jasper.h|jas_image.h|lib(X11|GL|Xm|freetype)\.[^\d]*)$/;
@@ -218,21 +248,21 @@ sub build_binaries {
     print STDERR "[/System ] $_\n" foreach ($self->find_file('/System', $re));
     print STDERR "[/Library] $_\n" foreach ($self->find_file('/Library', $re));
     print STDERR "[/Network] $_\n" foreach ($self->find_file('/Network', $re));
-
-    print STDERR "Dumping some pkg-info:\n";
-    print STDERR "[gtk2 cflags] " . $self->run_stdout2str(qw[pkg-config --cflags gtk+-2.0]) . "\n";
-    print STDERR "[gtk2 libs  ] " . $self->run_stdout2str(qw[pkg-config --libs gtk+-2.0]) . "\n";
-    for my $pkg (qw[gtk+-2.0 gl glu glut x11 xt xext xmu]) {
-      print STDERR "[prefix     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=prefix], $pkg) . "\n";
-      print STDERR "[libdir     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=libdir], $pkg) . "\n";
-      print STDERR "[includedir $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=includedir], $pkg) . "\n";
-    }
   }
   
   unless ($build_target) {
-    warn "###FATAL### No supported GUI subsystem (GTK2, X11/Motif) detected! (gonna exit)\n";
-    warn "### for GTK2 you need: gtk+-2.0, gdk-2.0, cairo + X11/Xlib.h\n";
-    warn "### for X11/Motif you need: -lXm, -lX11 + Xm/Xm.h, X11/Xlib.h\n";
+    warn <<'MARKER'
+###FATAL### No supported GUI subsystem (GTK2, X11/Motif) detected! (gonna exit)
+### for GTK2 you need: gtk+-2.0, gdk-2.0, cairo + X11/Xlib.h
+### for X11/Motif you need: -lXm, -lX11 + Xm/Xm.h, X11/Xlib.h
+### 
+### on Debian/Ubuntu you need to install: 
+###  $ aptitude install libgtk2.0-dev libcairo2-dev libx11-dev libglu-dev
+### 
+### on RedHat/CentOS/Fedora you need to install: 
+###  $ yum install gtk2-devel cairo-devel libX11-devel libGLU-devel
+###
+MARKER
     die;
   }
   
